var Helpers, View, crypto, haml, markdown, utils;
haml = require('hamljs');
utils = require('./utils');
markdown = require('node-markdown').Markdown;
crypto = require('crypto');
require('./patches');
/*
View object
*/
View = (function() {
  function View(file, encoding, options, absolute_path) {
    this.file = file;
    this.encoding = encoding;
    this.options = options != null ? options : {};
    this.absolute_path = absolute_path != null ? absolute_path : false;
    if (!this.absolute_path) {
      this.file = View.templatesDir() + this.file;
    }
  }
  View._templatesDir = null;
  View.templatesDir = function() {
    if (arguments.length > 0) {
      return View._templatesDir = arguments[0];
    } else {
      return View._templatesDir;
    }
  };
  View._globals = {};
  View.globals = function() {
    if (arguments.length > 0) {
      return View._globals = arguments[0];
    } else {
      return View._globals;
    }
  };
  View.prototype.render = function(res, locals, callback) {
    var layoutFile, options, that;
    layoutFile = View.templatesDir() + '/layout.haml';
    that = this;
    options = utils.merge(this.options, {
      locals: View.globals()
    });
    return this.partial(locals, function(err, data) {
      options.locals = utils.merge(options.locals, locals);
      options.locals.body = data;
      options.locals.__proto__ = Helpers;
      return haml.renderFile(layoutFile, that.encoding, options, function(err, data) {
        if (err) {
          return callback(err);
        }
        res.writeHead(200, {
          'content-type': 'text/html'
        });
        res.end(data);
        return callback();
      });
    });
  };
  View.prototype.partial = function(locals, callback) {
    var options, templateFile;
    templateFile = this.file;
    locals = utils.merge(View.globals(), locals);
    options = utils.merge(this.options, {
      locals: locals
    });
    options.locals.__proto__ = Helpers;
    return haml.renderFile(templateFile, this.encoding, options, function(err, data) {
      if (err) {
        return callback(err);
      }
      return callback(null, data);
    });
  };
  return View;
})();
/*
View helpers
*/
Helpers = (function() {
  function Helpers() {}
  Helpers.markdown = function(str) {
    return markdown(str);
  };
  Helpers.summary = function(body) {
    return body.split('<!-- more -->')[0].replace(/\.$/, '&hellip;');
  };
  Helpers.gravatar = function(email, size) {
    if (size == null) {
      size = 50;
    }
    return 'http://www.gravatar.com/avatar/' + crypto.createHash('md5').update(email.trim().toLowerCase()).digest('hex') + ("?r=pg&s=" + size + ".jpg&d=identicon");
  };
  return Helpers;
})();
/*
Module Exports
*/
module.exports.View = View;
module.exports.Helpers = Helpers;